import * as tslib_1 from "tslib";
import * as React from 'react';
import { Provider } from './index';
import Web3 from 'web3';
import { createRequest, getRequest, payRequest } from './utils';
var ETH_NETWORKS = {
    1: {
        url: 'https://mainnet.infura.io/BQBjfSi5EKSCQQpXebO',
        name: 'main'
    },
    4: {
        url: 'https://rinkeby.infura.io/BQBjfSi5EKSCQQpXebO',
        name: 'rinkeby'
    }
};
var NETWORK_NAME = process.env.REACT_APP_NETWORK;
var RequestNetworkProvider = (function (_super) {
    tslib_1.__extends(RequestNetworkProvider, _super);
    function RequestNetworkProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            requestNetwork: undefined,
            currentAccount: '',
            currentNetwork: ''
        };
        _this.fetchAccounts = function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var web3, currentAccount, account;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(typeof window.web3 !== 'undefined')) return [3, 2];
                        web3 = new Web3(window.web3.currentProvider);
                        currentAccount = this.state.currentAccount;
                        return [4, web3.eth.getAccounts()];
                    case 1:
                        account = _a.sent();
                        if (account.length > 0 && currentAccount === '') {
                            return [2, this.setState({ currentAccount: account[0] })];
                        }
                        if (currentAccount !== account[0]) {
                            return [2, this.setState({ currentAccount: account[0] })];
                        }
                        _a.label = 2;
                    case 2: return [2];
                }
            });
        }); };
        return _this;
    }
    RequestNetworkProvider.prototype.initPoll = function () {
        if (!this.interval) {
            this.interval = setInterval(this.fetchAccounts, 1000);
        }
    };
    RequestNetworkProvider.prototype.initRequestProvider = function (web3, networkId, networkName) {
        var _this = this;
        import('@requestnetwork/request-network.js')
            .then(function (RequestNetwork) {
            return _this.setState({
                requestNetwork: new RequestNetwork.default(web3.currentProvider, networkId),
                currentNetwork: networkName
            });
        })
            .catch(function (e) { return console.error(e); });
    };
    RequestNetworkProvider.prototype.initWeb3 = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var web3, networkId, networkName, web3, networkId, networkName;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(typeof window.web3 !== 'undefined')) return [3, 3];
                        web3 = new Web3(window.web3.currentProvider);
                        return [4, web3.eth.net.getId()];
                    case 1:
                        networkId = _a.sent();
                        return [4, web3.eth.net.getNetworkType(networkId)];
                    case 2:
                        networkName = _a.sent();
                        this.initRequestProvider(web3, networkId, networkName);
                        return [3, 6];
                    case 3:
                        web3 = new Web3(new Web3.providers.HttpProvider(ETH_NETWORKS[4].url));
                        return [4, web3.eth.net.getId()];
                    case 4:
                        networkId = _a.sent();
                        return [4, web3.eth.net.getNetworkType(networkId)];
                    case 5:
                        networkName = _a.sent();
                        this.initRequestProvider(web3, networkId, networkName);
                        _a.label = 6;
                    case 6: return [2];
                }
            });
        });
    };
    RequestNetworkProvider.prototype.componentDidMount = function () {
        this.initWeb3();
        this.initPoll();
    };
    RequestNetworkProvider.prototype.componentDidUpdate = function (_a, prevState) {
        var onInit = _a.onInit;
        if (prevState.requestNetwork === undefined && this.state.requestNetwork) {
            onInit();
        }
    };
    RequestNetworkProvider.prototype.render = function () {
        var _a = this.state, requestNetwork = _a.requestNetwork, currentNetwork = _a.currentNetwork, currentAccount = _a.currentAccount;
        if (!requestNetwork) {
            return null;
        }
        return (React.createElement(Provider, { value: {
                create: function (paymentAddress, amount, data) {
                    return createRequest(requestNetwork, paymentAddress, amount, data, {
                        currentAccount: currentAccount
                    });
                },
                get: function (id) { return getRequest(requestNetwork, id); },
                pay: function (requestId, amount) {
                    return payRequest(requestNetwork, requestId, amount);
                },
                isReady: true,
                currentNetwork: currentNetwork,
                networkMismatch: !(NETWORK_NAME === currentNetwork),
                currentAccount: currentAccount
            } }, this.props.children));
    };
    return RequestNetworkProvider;
}(React.Component));
export { RequestNetworkProvider };
export default RequestNetworkProvider;
//# sourceMappingURL=Provider.js.map